<img alt="FastCS Logo" align="right" width="100" height="100" src="https://raw.githubusercontent.com/DiamondLightSource/FastCS/main/docs/images/fastcs.svg" target=https://github.com/DiamondLightSource/FastCS>

[![CI](https://github.com/DiamondLightSource/FastCS/actions/workflows/ci.yml/badge.svg)](https://github.com/DiamondLightSource/FastCS/actions/workflows/ci.yml)
[![Coverage](https://codecov.io/gh/DiamondLightSource/FastCS/branch/main/graph/badge.svg)](https://codecov.io/gh/DiamondLightSource/FastCS)
[![PyPI](https://img.shields.io/pypi/v/fastcs.svg)](https://pypi.org/project/fastcs)
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://www.apache.org/licenses/LICENSE-2.0)

# FastCS

Source          | <https://github.com/DiamondLightSource/FastCS>
:---:           | :---:
PyPI            | `pip install fastcs`
Documentation   | <https://diamondlightsource.github.io/FastCS>
Releases        | <https://github.com/DiamondLightSource/FastCS/releases>

FastCS is a control system agnostic framework for building Device support in Python that
will work for both EPICS and Tango without depending on either.

<!-- README only content. Anything below this line won't be included in index.md -->

See https://diamondlightsource.github.io/FastCS for more detailed documentation.
